{% load i18n wagtailroutablepage_tags %}

<ul>
    {% regroup archives by year as year_list %}
    {% for year in year_list %}
        <li>
            <a href="{% routablepageurl blog_page "entries_by_date" year.grouper %}">
                <i class="fa fa-angle-down"></i> {{ year.grouper }}
            </a>
            <ul>
                {% regroup year.list by month as month_list %}
                {% for month in month_list reversed %}
                    <li>
                        <a href="{% routablepageurl blog_page "entries_by_date" year.grouper month.list.0|date:"m" %}">
                            <i class="fa fa-angle-double-right"></i> {{ month.list.0|date:"F" }}
                        </a>
                    </li>
                {% endfor %}
            </ul>
        </li>
    {% empty %}
        {% trans 'No entry archives yet' %}
    {% endfor %}
</ul>