# -*- coding: utf-8 -*-

__author__ = 'Marc Tudurí'
__email__ = 'marctc@gmail.com'
__version__ = '0.4.1'

PUPUT_APPS = (
    # Wagtail apps
    'wagtail.wagtailcore',
    'wagtail.wagtailadmin',
    'wagtail.wagtaildocs',
    'wagtail.wagtailsnippets',
    'wagtail.wagtailusers',
    'wagtail.wagtailimages',
    'wagtail.wagtailembeds',
    'wagtail.wagtailsearch',
    'wagtail.wagtailsites',
    'wagtail.wagtailredirects',
    'wagtail.wagtailforms',
    'wagtail.contrib.wagtailsitemaps',
    'wagtail.contrib.wagtailroutablepage',

    # Third-party apps
    'compressor',
    'taggit',
    'modelcluster',

    # Puput apps
    'puput',
)
